.icon[data-v-e8d572f6]{display:inline-block;vertical-align:middle}.form-select[data-v-931b50ef]{background-image:none}.loading-bar[data-v-02de0c28]{animation:load-02de0c28 1s infinite,pulse-02de0c28 2s infinite;width:0}.loading-bar2[data-v-02de0c28]{animation:load-02de0c28 2s infinite,pulse-02de0c28 2s infinite;width:0}@keyframes load-02de0c28{0%{width:0}70%{width:100%}to{width:0}}@keyframes pulse-02de0c28{0%,to{opacity:1}50%{opacity:.5}}
