import{a as r,o as t,c as a,ai as o,b as s}from"./DbTgESvQ.js";const c={},n={class:"text-center rounded border-2 border-dashed border-gray-300 dark:border-gray-700 bg-gray-50 dark:bg-gray-800 py-4 text-sm"},d=s("span",{class:"text-gray-400"}," Empty ",-1);function _(e,l){return t(),a("div",n,[o(e.$slots,"default",{},()=>[d])])}const b=r(c,[["render",_]]);export{b as _};
